==> synfig_0.61.08.orig.tar.gz: synfig-0.61.08/src/synfig/valuenode_twotone.h <==
/* === S Y N F I G ========================================================= */
/*!	\file valuenode_twotone.h
**	\brief Header file for implementation of the "Two-Tone" valuenode conversion.
**
**	$Id: valuenode_twotone.h 1643 2008-02-09 19:12:18Z dooglus $
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**	Copyright (c) 2008 Chris Moore
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_VALUENODE_TWOTONE_H
#define __SYNFIG_VALUENODE_TWOTONE_H

/* === H E A D E R S ======================================================= */

#include "valuenode.h"

/* === M A C R O S ========================================================= */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfig {

struct ValueNode_TwoTone : public LinkableValueNode
{
	typedef etl::handle<ValueNode_TwoTone> Handle;
	typedef etl::handle<const ValueNode_TwoTone> ConstHandle;

protected:

	ValueNode_TwoTone();

private:

	ValueNode::RHandle ref_a;
	ValueNode::RHandle ref_b;

public:

	virtual ~ValueNode_TwoTone();

	virtual bool set_link_vfunc(int i,ValueNode::Handle x);

	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;

	virtual int link_count()const;

	virtual String link_local_name(int i)const;
	virtual String link_name(int i)const;
	virtual int get_link_index_from_name(const String &name)const;

	virtual ValueBase operator()(Time t)const;

	virtual String get_name()const;
	virtual String get_local_name()const;

//	static bool check_type(const ValueBase::Type &type);

	LinkableValueNode* create_new()const;

public:
	using synfig::LinkableValueNode::get_link_vfunc;

	using synfig::LinkableValueNode::set_link_vfunc;
	static bool check_type(ValueBase::Type type);
	static ValueNode_TwoTone* create(const ValueBase &x=ValueBase::TYPE_GRADIENT);
}; // END of class ValueNode_TwoTone

}; // END of namespace synfig

/* === E N D =============================================================== */

#endif

==> synfig_0.61.09.orig.tar.gz: synfig-0.61.09/src/synfig/valuenode_twotone.h <==
/* === S Y N F I G ========================================================= */
/*!	\file valuenode_twotone.h
**	\brief Header file for implementation of the "Two-Tone" valuenode conversion.
**
**	$Id: valuenode_twotone.h 1888 2008-03-08 14:38:31Z dooglus $
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**	Copyright (c) 2008 Chris Moore
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_VALUENODE_TWOTONE_H
#define __SYNFIG_VALUENODE_TWOTONE_H

/* === H E A D E R S ======================================================= */

#include "valuenode.h"

/* === M A C R O S ========================================================= */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfig {

class ValueNode_TwoTone : public LinkableValueNode
{
	ValueNode::RHandle ref_a;
	ValueNode::RHandle ref_b;

	ValueNode_TwoTone(const ValueBase &value);

public:

	typedef etl::handle<ValueNode_TwoTone> Handle;
	typedef etl::handle<const ValueNode_TwoTone> ConstHandle;

	virtual ~ValueNode_TwoTone();

	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;

	virtual int link_count()const;

	virtual String link_local_name(int i)const;
	virtual String link_name(int i)const;
	virtual int get_link_index_from_name(const String &name)const;

	virtual ValueBase operator()(Time t)const;

	virtual String get_name()const;
	virtual String get_local_name()const;

protected:
	LinkableValueNode* create_new()const;
	virtual bool set_link_vfunc(int i,ValueNode::Handle x);

public:
	using synfig::LinkableValueNode::get_link_vfunc;

	using synfig::LinkableValueNode::set_link_vfunc;
	static bool check_type(ValueBase::Type type);
	static ValueNode_TwoTone* create(const ValueBase &x);
}; // END of class ValueNode_TwoTone

}; // END of namespace synfig

/* === E N D =============================================================== */

#endif
